﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

using System.Drawing.Drawing2D;
using System.Drawing.Text;
using System.IO;

namespace howto_make_icon
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            Bitmap bm16 = MakeBitmap16();
            Bitmap bm24 = MakeBitmap24();
            Bitmap bm32 = MakeBitmap32();
            Bitmap bm48 = MakeBitmap48();
            Bitmap bm256 = MakeBitmap256();

            pic16.Image = bm16;
            pic24.Image = bm24;
            pic32.Image = bm32;
            pic48.Image = bm48;
            pic256.Image = bm256;

            Bitmap[] bitmaps = { bm16, bm32, bm24, bm48, bm256 };

            // Save the icon into a file.
            string filename = "result.ico";
            IconFactory.SavePngsAsIcon(bitmaps, filename, true);

            // Make this form use the icon.
            this.Icon = IconFactory.SavePngsAsIcon(bitmaps);
        }

        private Bitmap MakeBitmap(int wid, int hgt)
        {
            Bitmap bm = new Bitmap(wid, hgt);
            using (Graphics gr = Graphics.FromImage(bm))
            {
                gr.SmoothingMode = SmoothingMode.AntiAlias;
                gr.Clear(Color.Transparent);

                float cx = wid / 2f;
                float cy = hgt / 2f;
                for (int i = 5; i < wid; i += 5)
                {
                    RectangleF rect = new RectangleF(cx - i, cy - i, 2 * i, 2 * i);
                    gr.DrawEllipse(Pens.Red, rect);
                }
            }
            return bm;
        }

        private Bitmap MakeBitmap256()
        {
            const int wid = 256;
            const int hgt = 256;
            Bitmap bm = new Bitmap(wid, hgt);
            using (Graphics gr = Graphics.FromImage(bm))
            {
                gr.SmoothingMode = SmoothingMode.AntiAlias;
                gr.TextRenderingHint = TextRenderingHint.AntiAliasGridFit;
                gr.Clear(Color.Transparent);

                const int thickness = 10;
                RectangleF rect = new RectangleF(
                    thickness / 2f, thickness / 2f,
                    wid - thickness, hgt - thickness);
                using (Brush brush = new LinearGradientBrush(
                    new PointF(0, 0), new PointF(0, hgt),
                    Color.LightGreen, Color.Green))
                {
                    using (Brush pen_brush = new LinearGradientBrush(
                        new PointF(0, 0), new PointF(0, hgt),
                        Color.Green, Color.LightGreen))
                    {
                        using (Pen pen = new Pen(pen_brush, thickness))
                        {
                            const float radius = 4 * thickness;
                            gr.DrawRoundedRectangle(rect, brush, pen, radius);
                        }
                    }
                }

                using (StringFormat sf = new StringFormat())
                {
                    sf.Alignment = StringAlignment.Center;
                    sf.LineAlignment = StringAlignment.Center;
                    const float font_size = 50;
                    using (Font font = new Font("Times New Roman",
                        font_size, FontStyle.Bold))
                    {
                        float cx = wid / 2f;
                        float y1 = hgt / 3f;
                        float y2 = hgt / 3f * 2;

                        const float font_scale = 1.75f;
                        GraphicsState state = gr.Save();

                        gr.ResetTransform();
                        gr.ScaleTransform(1, font_scale);
                        gr.TranslateTransform(cx, y1, MatrixOrder.Append);
                        gr.DrawString("C#", font, Brushes.Green, 0, 0, sf);

                        gr.ResetTransform();
                        gr.ScaleTransform(1, font_scale);
                        gr.TranslateTransform(cx, y2, MatrixOrder.Append);
                        gr.DrawString("Helper", font, Brushes.LightGreen, 0, 0, sf);

                        gr.Restore(state);
                    }
                }
            } // using gr
            return bm;
        }

        private Bitmap MakeBitmap48()
        {
            const int wid = 48;
            const int hgt = 48;
            Bitmap bm = new Bitmap(wid, hgt);
            using (Graphics gr = Graphics.FromImage(bm))
            {
                gr.SmoothingMode = SmoothingMode.AntiAlias;
                gr.TextRenderingHint = TextRenderingHint.AntiAliasGridFit;
                gr.Clear(Color.Transparent);

                const int thickness = 5;
                RectangleF rect = new RectangleF(
                    thickness / 2f, thickness / 2f,
                    wid - thickness, hgt - thickness);
                using (Brush brush = new LinearGradientBrush(
                    new PointF(0, 0), new PointF(0, hgt),
                    Color.LightGreen, Color.Green))
                {
                    using (Brush pen_brush = new LinearGradientBrush(
                        new PointF(0, 0), new PointF(0, hgt),
                        Color.Green, Color.LightGreen))
                    {
                        using (Pen pen = new Pen(pen_brush, thickness))
                        {
                            const float radius = 2 * thickness;
                            gr.DrawRoundedRectangle(rect, brush, pen, radius);
                        }
                    }
                }

                using (StringFormat sf = new StringFormat())
                {
                    sf.Alignment = StringAlignment.Center;
                    sf.LineAlignment = StringAlignment.Center;
                    const float font_size = 15;
                    using (Font font = new Font("Times New Roman",
                        font_size, FontStyle.Bold))
                    {
                        float x1 = wid / 3f;
                        float x2 = wid / 2f;
                        float x3 = wid / 3f * 2;
                        float y1 = hgt / 3f;
                        float y2 = hgt / 2f;
                        float y3 = hgt / 3f * 2;

                        const float font_scale = 1f;
                        GraphicsState state = gr.Save();

                        gr.ResetTransform();
                        gr.ScaleTransform(1, font_scale);
                        gr.TranslateTransform(x1, y1, MatrixOrder.Append);
                        gr.DrawString("C", font, Brushes.DarkGreen, 0, 0, sf);

                        gr.ResetTransform();
                        gr.ScaleTransform(1, font_scale);
                        gr.TranslateTransform(x3, y3, MatrixOrder.Append);
                        gr.DrawString("H", font, Brushes.LightGreen, 0, 0, sf);

                        using (Font font2 = new Font("Times New Roman",
                            font_size * 1.2f, FontStyle.Bold))
                        {
                            gr.ResetTransform();
                            gr.ScaleTransform(1, font_scale);
                            gr.TranslateTransform(x2, y2, MatrixOrder.Append);
                            gr.DrawString("#", font2, Brushes.Green, 0, 0, sf);
                        }

                        gr.Restore(state);
                    }
                }
            } // using gr
            return bm;
        }

        private Bitmap MakeBitmap32()
        {
            const int wid = 32;
            const int hgt = 32;
            Bitmap bm = new Bitmap(wid, hgt);
            using (Graphics gr = Graphics.FromImage(bm))
            {
                gr.SmoothingMode = SmoothingMode.AntiAlias;
                gr.TextRenderingHint = TextRenderingHint.AntiAlias;
                gr.Clear(Color.Transparent);

                const int thickness = 3;
                RectangleF rect = new RectangleF(
                    thickness / 2f, thickness / 2f,
                    wid - thickness, hgt - thickness);
                using (Brush brush = new LinearGradientBrush(
                    new PointF(0, 0), new PointF(0, hgt),
                    Color.LightGreen, Color.Green))
                {
                    using (Brush pen_brush = new LinearGradientBrush(
                        new PointF(0, 0), new PointF(0, hgt),
                        Color.Green, Color.LightGreen))
                    {
                        using (Pen pen = new Pen(pen_brush, thickness))
                        {
                            const float radius = 2 * thickness;
                            gr.DrawRoundedRectangle(rect, brush, pen, radius);
                        }
                    }
                }

                using (StringFormat sf = new StringFormat())
                {
                    sf.Alignment = StringAlignment.Center;
                    sf.LineAlignment = StringAlignment.Center;
                    const float font_size = 10;
                    using (Font font = new Font("Times New Roman",
                        font_size, FontStyle.Bold))
                    {
                        float x1 = wid / 3f;
                        float x2 = wid / 2f;
                        float x3 = wid / 3f * 2;
                        float y1 = hgt / 3f;
                        float y2 = hgt / 2f;
                        float y3 = hgt / 3f * 2;

                        const float font_scale = 1f;
                        GraphicsState state = gr.Save();

                        gr.ResetTransform();
                        gr.ScaleTransform(1, font_scale);
                        gr.TranslateTransform(x1, y1, MatrixOrder.Append);
                        gr.DrawString("C", font, Brushes.DarkGreen, 0, 0, sf);

                        gr.ResetTransform();
                        gr.ScaleTransform(1, font_scale);
                        gr.TranslateTransform(x3, y3, MatrixOrder.Append);
                        gr.DrawString("H", font, Brushes.DarkGreen, 0, 0, sf);

                        using (Font font2 = new Font("Times New Roman",
                            font_size * 1.2f, FontStyle.Bold))
                        {
                            gr.ResetTransform();
                            gr.ScaleTransform(1, font_scale);
                            gr.TranslateTransform(x2, y2, MatrixOrder.Append);
                            gr.DrawString("#", font2, Brushes.DarkGreen, 0, 0, sf);
                        }

                        gr.Restore(state);
                    }
                }
            } // using gr
            return bm;
        }
        private Bitmap MakeBitmap24()
        {
            const int wid = 24;
            const int hgt = 24;
            Bitmap bm = new Bitmap(wid, hgt);
            using (Graphics gr = Graphics.FromImage(bm))
            {
                gr.SmoothingMode = SmoothingMode.AntiAlias;
                gr.TextRenderingHint = TextRenderingHint.AntiAliasGridFit;
                gr.Clear(Color.Transparent);

                const int thickness = 1;
                using (Pen pen = new Pen(Color.DarkGreen, thickness))
                {
                    RectangleF rect = new RectangleF(
                        thickness / 2f, thickness / 2f,
                        wid - thickness, hgt - thickness);
                    gr.FillRectangle(Brushes.LightGreen, rect);
                    gr.DrawRectangle(pen, rect);
                }

                using (StringFormat sf = new StringFormat())
                {
                    sf.Alignment = StringAlignment.Center;
                    sf.LineAlignment = StringAlignment.Center;
                    const float font_size = 10;
                    using (Font font = new Font("Times New Roman",
                        font_size, FontStyle.Bold))
                    {
                        float x1 = wid / 3f;
                        float x3 = wid / 3f * 2;
                        float y1 = hgt / 3f;
                        float y3 = hgt / 3f * 2;

                        const float font_scale = 1f;
                        GraphicsState state = gr.Save();

                        gr.ResetTransform();
                        gr.ScaleTransform(1, font_scale);
                        gr.TranslateTransform(x1, y1, MatrixOrder.Append);
                        gr.DrawString("C#", font, Brushes.DarkGreen, 0, 0, sf);

                        gr.ResetTransform();
                        gr.ScaleTransform(1, font_scale);
                        gr.TranslateTransform(x3, y3, MatrixOrder.Append);
                        gr.DrawString("H", font, Brushes.DarkGreen, 0, 0, sf);

                        gr.Restore(state);
                    }
                }
            } // using gr
            return bm;
        }

        private Bitmap MakeBitmap16()
        {
            const int wid = 16;
            const int hgt = 16;
            Bitmap bm = new Bitmap(wid, hgt);
            using (Graphics gr = Graphics.FromImage(bm))
            {
                gr.SmoothingMode = SmoothingMode.AntiAlias;
                gr.TextRenderingHint = TextRenderingHint.AntiAliasGridFit;
                gr.Clear(Color.Transparent);

                const int thickness = 1;
                using (Pen pen = new Pen(Color.DarkGreen, thickness))
                {
                    RectangleF rect = new RectangleF(
                        thickness / 2f, thickness / 2f,
                        wid - thickness, hgt - thickness);
                    gr.FillRectangle(Brushes.LightGreen, rect);
                    gr.DrawRectangle(pen, rect);
                }

                using (StringFormat sf = new StringFormat())
                {
                    sf.Alignment = StringAlignment.Center;
                    sf.LineAlignment = StringAlignment.Center;
                    const float font_size = 6;
                    using (Font font = new Font("Arial",
                        font_size, FontStyle.Bold))
                    {
                        float cx = wid / 2f;
                        float y1 = hgt / 3f;
                        float y3 = hgt / 3f * 2;

                        const float font_scale = 1f;
                        GraphicsState state = gr.Save();

                        gr.ResetTransform();
                        gr.ScaleTransform(1, font_scale);
                        gr.TranslateTransform(cx, y1, MatrixOrder.Append);
                        gr.DrawString("C#", font, Brushes.DarkGreen, 0, 0, sf);

                        gr.ResetTransform();
                        gr.ScaleTransform(1, font_scale);
                        gr.TranslateTransform(cx, y3, MatrixOrder.Append);
                        gr.DrawString("H", font, Brushes.DarkGreen, 0, 0, sf);

                        gr.Restore(state);
                    }
                }
            } // using gr
            return bm;
        }
    }
}
